@@ -2,9 +2,7 @@ use strict;
 use warnings;
 
 package XML::Rabbit;
-{
-  $XML::Rabbit::VERSION = '0.4.0';
-}
+$XML::Rabbit::VERSION = '0.4.1';
 use 5.008;
 
 # ABSTRACT: Consume XML with Moose and xpath queries
@@ -46,7 +44,7 @@ sub init_meta {
         for   => $opts{for_class},
         roles => ['XML::Rabbit::Node']
     );
-    return Class::MOP::class_of($opts{for_class});
+    return Moose::Util::find_meta($opts{for_class});
 }
 
 1;
@@ -55,7 +53,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -63,11 +61,23 @@ XML::Rabbit - Consume XML with Moose and xpath queries
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 SYNOPSIS
 
-    my $xhtml = W3C::XHTML->new( file => 'index.xhtml' );
+    my $xhtml = W3C::XHTML->new(
+        file => 'index.xhtml',
+
+        # or string...
+        xml => $xml,
+
+        # or filehandle...
+        fh => $fh,
+
+        # or XML::LibXML::Document object
+        dom => $dom,
+    );
+
     print "Title: " . $xhtml->title . "\n";
     print "First image source: " . $xhtml->body->images->[0]->src . "\n";
 
@@ -395,7 +405,7 @@ Robin Smidsrød <robin@smidsrod.no>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Robin Smidsrød.
+This software is copyright (c) 2015 by Robin Smidsrød.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
