@@ -2,9 +2,7 @@ use strict;
 use warnings;
 
 package XML::Rabbit::Role::Document;
-{
-  $XML::Rabbit::Role::Document::VERSION = '0.4.0';
-}
+$XML::Rabbit::Role::Document::VERSION = '0.4.1';
 use Moose::Role;
 
 use XML::LibXML 1.69 ();
@@ -59,7 +57,7 @@ has '_parser' => (
     is      => 'ro',
     isa     => 'XML::LibXML',
     lazy    => 1,
-    default => sub { XML::LibXML->new(), },
+    default => sub { XML::LibXML->new( huge => 1 ), },
 );
 
 
@@ -79,7 +77,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -87,7 +85,7 @@ XML::Rabbit::Role::Document - XML Document base class
 
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 SYNOPSIS
 
@@ -135,7 +133,7 @@ Robin Smidsrød <robin@smidsrod.no>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Robin Smidsrød.
+This software is copyright (c) 2015 by Robin Smidsrød.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
